==> synergy_1.0.14.orig.tar.gz: synergy-1.0.14/cmd/synergyc/CClientTaskBarReceiver.cpp <==
/*
 * synergy -- mouse and keyboard sharing utility
 * Copyright (C) 2003 Chris Schoeneman
 * 
 * This package is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * found in the file COPYING that should have accompanied this file.
 * 
 * This package is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#include "CClientTaskBarReceiver.h"
#include "CClient.h"
#include "CLock.h"
#include "TMethodJob.h"
#include "CArch.h"

//
// CClientTaskBarReceiver
//

CClientTaskBarReceiver::CClientTaskBarReceiver() :
	m_quit(NULL),
	m_state(kNotRunning),
	m_client(NULL)
{
	// create a job for getting notification when the client's
	// status changes.
	m_job = new TMethodJob<CClientTaskBarReceiver>(this,
							&CClientTaskBarReceiver::statusChanged, NULL);
}

CClientTaskBarReceiver::~CClientTaskBarReceiver()
{
	if (m_client != NULL) {
		m_client->removeStatusJob(m_job);
	}
	delete m_job;
	delete m_quit;
}

void
CClientTaskBarReceiver::setClient(CClient* client)
{
	{
		CLock lock(&m_mutex);
		if (m_client != client) {
			if (m_client != NULL) {
				m_client->removeStatusJob(m_job);
			}
			m_client = client;
			if (m_client != NULL) {
				m_client->addStatusJob(m_job);
			}
		}
	}
	ARCH->updateReceiver(this);
}

void
CClientTaskBarReceiver::setState(EState state)
{
	{
		CLock lock(&m_mutex);
		m_state = state;
	}
	ARCH->updateReceiver(this);
}

void
CClientTaskBarReceiver::setQuitJob(IJob* job)
{
	CLock lock(&m_mutex);
	delete m_quit;
	m_quit = job;
}

CClientTaskBarReceiver::EState
CClientTaskBarReceiver::getState() const
{
	return m_state;
}

CClient*
CClientTaskBarReceiver::getClient() const
{
	return m_client;
}

void
CClientTaskBarReceiver::lock() const
{
	m_mutex.lock();
}

void
CClientTaskBarReceiver::unlock() const
{
	m_mutex.unlock();
}

std::string
CClientTaskBarReceiver::getToolTip() const
{
	switch (m_state) {
	case kNotRunning:
		return "Synergy:  Not running";

	case kNotWorking:
		return CString("Synergy:  ") + m_errorMessage;

	case kNotConnected:
		return "Synergy:  Waiting for clients";

	case kConnected:
		return "Synergy:  Connected";

	default:
		return "";
	}
}

void
CClientTaskBarReceiver::quit()
{
	if (m_quit != NULL) {
		m_quit->run();
	}
}

void
CClientTaskBarReceiver::onStatusChanged()
{
	// do nothing
}

void
CClientTaskBarReceiver::statusChanged(void*)
{
	// update our status
	switch (m_client->getStatus(&m_errorMessage)) {
	case CClient::kNotRunning:
		setState(kNotRunning);
		break;

	case CClient::kRunning:
		setState(kConnected);
		break;

	case CClient::kError:
		setState(kNotWorking);
		break;

	default:
		break;
	}

	// let subclasses have a go
	onStatusChanged();
}

==> synergy_1.2.2.orig.tar.gz: synergy-1.2.2/cmd/synergyc/CClientTaskBarReceiver.cpp <==
/*
 * synergy -- mouse and keyboard sharing utility
 * Copyright (C) 2003 Chris Schoeneman
 * 
 * This package is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * found in the file COPYING that should have accompanied this file.
 * 
 * This package is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#include "CClientTaskBarReceiver.h"
#include "CClient.h"
#include "CLock.h"
#include "IEventQueue.h"
#include "CArch.h"

//
// CClientTaskBarReceiver
//

CClientTaskBarReceiver::CClientTaskBarReceiver() :
	m_state(kNotRunning)
{
	// do nothing
}

CClientTaskBarReceiver::~CClientTaskBarReceiver()
{
	// do nothing
}

void
CClientTaskBarReceiver::updateStatus(CClient* client, const CString& errorMsg)
{
	{
		// update our status
		m_errorMessage = errorMsg;
		if (client == NULL) {
			if (m_errorMessage.empty()) {
				m_state = kNotRunning;
			}
			else {
				m_state = kNotWorking;
			}
		}
		else {
			if (client->isConnected()) {
				m_state = kConnected;
			}
			else if (client->isConnecting()) {
				m_state = kConnecting;
			}
			else {
				m_state = kNotConnected;
			}
		}

		// let subclasses have a go
		onStatusChanged(client);
	}

	// tell task bar
	ARCH->updateReceiver(this);
}

CClientTaskBarReceiver::EState
CClientTaskBarReceiver::getStatus() const
{
	return m_state;
}

const CString&
CClientTaskBarReceiver::getErrorMessage() const
{
	return m_errorMessage;
}

void
CClientTaskBarReceiver::quit()
{
	EVENTQUEUE->addEvent(CEvent(CEvent::kQuit));
}

void
CClientTaskBarReceiver::onStatusChanged(CClient*)
{
	// do nothing
}

void
CClientTaskBarReceiver::lock() const
{
	// do nothing
}

void
CClientTaskBarReceiver::unlock() const
{
	// do nothing
}

std::string
CClientTaskBarReceiver::getToolTip() const
{
	switch (m_state) {
	case kNotRunning:
		return "Synergy:  Not running";

	case kNotWorking:
		return CString("Synergy:  ") + m_errorMessage;

	case kNotConnected:
		return CString("Synergy:  Not connected:  ") + m_errorMessage;

	case kConnecting:
		return "Synergy:  Connecting...";

	case kConnected:
		return "Synergy:  Connected";

	default:
		return "";
	}
}
